class DataCollectionModuleKeyConstants:
    NAME = "name"
    HOSTNAME = "hostname"
    IP = "ip"
    NETMASK = "netmask"
    BROADCAST = "broadcast"
    GATEWAY = "gateway"
    DNS = "dns"
    APU_IP = "apu_ip"
    HOMEPAGE = "homepage"
    RIO_TYPE = "rio_type"
    TOUCH_TYPE = "touch_type"

class RioTypes:
    RIO3 = "rtl_rio3"
    RIO4 = "rtl_rio4"

class DataCollectionModuleTypes:
    MANO_DCM = "manodcm"
    RPI4_DCM = "rpi4dcm"
